GpuTracer

Struct GpuTracer 

pub struct GpuTracer { /* private fields */ }
The GPU photon tracer.

Implementations

Source

impl GpuTracer

pub async fn new() -> Result<Self, String>

Create a new GPU tracer, requesting a wgpu device.

pub async fn trace_isotropic( &self, num_photons: u32, c_res_deg: f32, g_res_deg: f32, ) -> GpuDetectorResult

Trace photons from an isotropic source in free space.

pub async fn trace_lambertian( &self, num_photons: u32, c_res_deg: f32, g_res_deg: f32, ) -> GpuDetectorResult

Trace photons from a Lambertian source in free space.

pub async fn trace_with_scene( &self, num_photons: u32, c_res_deg: f32, g_res_deg: f32, source_type: SourceType, source_flux: f32, primitives: &[GpuPrimitive], materials: &[GpuMaterial], ) -> GpuDetectorResult

Trace with scene geometry and materials.

pub async fn trace_area_source( &self, num_photons: u32, c_res_deg: f32, g_res_deg: f32, source_flux: f32, center: [f32; 3], normal: [f32; 3], u_axis: [f32; 3], half_width: f32, half_height: f32, ) -> GpuDetectorResult

Trace from a rectangular diffuse area source in free space.

pub async fn trace_from_lvk( &self, num_photons: u32, c_res_deg: f32, g_res_deg: f32, source_flux: f32, cdf: &LvkCdf, primitives: &[GpuPrimitive], materials: &[GpuMaterial], ) -> GpuDetectorResult

Trace from an LDT source (FromLvk) with optional cover geometry.