pub struct GpuTracer { /* private fields */ }Expand description
The GPU photon tracer.
Implementations
Sourceimpl GpuTracer
impl GpuTracer
Sourcepub async fn trace_isotropic(
&self,
num_photons: u32,
c_res_deg: f32,
g_res_deg: f32,
) -> GpuDetectorResult
pub async fn trace_isotropic( &self, num_photons: u32, c_res_deg: f32, g_res_deg: f32, ) -> GpuDetectorResult
Trace photons from an isotropic source in free space.
Sourcepub async fn trace_lambertian(
&self,
num_photons: u32,
c_res_deg: f32,
g_res_deg: f32,
) -> GpuDetectorResult
pub async fn trace_lambertian( &self, num_photons: u32, c_res_deg: f32, g_res_deg: f32, ) -> GpuDetectorResult
Trace photons from a Lambertian source in free space.
Sourcepub async fn trace_with_scene(
&self,
num_photons: u32,
c_res_deg: f32,
g_res_deg: f32,
source_type: SourceType,
source_flux: f32,
primitives: &[GpuPrimitive],
materials: &[GpuMaterial],
) -> GpuDetectorResult
pub async fn trace_with_scene( &self, num_photons: u32, c_res_deg: f32, g_res_deg: f32, source_type: SourceType, source_flux: f32, primitives: &[GpuPrimitive], materials: &[GpuMaterial], ) -> GpuDetectorResult
Trace with scene geometry and materials.
Sourcepub async fn trace_area_source(
&self,
num_photons: u32,
c_res_deg: f32,
g_res_deg: f32,
source_flux: f32,
center: [f32; 3],
normal: [f32; 3],
u_axis: [f32; 3],
half_width: f32,
half_height: f32,
) -> GpuDetectorResult
pub async fn trace_area_source( &self, num_photons: u32, c_res_deg: f32, g_res_deg: f32, source_flux: f32, center: [f32; 3], normal: [f32; 3], u_axis: [f32; 3], half_width: f32, half_height: f32, ) -> GpuDetectorResult
Trace from a rectangular diffuse area source in free space.
Sourcepub async fn trace_from_lvk(
&self,
num_photons: u32,
c_res_deg: f32,
g_res_deg: f32,
source_flux: f32,
cdf: &LvkCdf,
primitives: &[GpuPrimitive],
materials: &[GpuMaterial],
) -> GpuDetectorResult
pub async fn trace_from_lvk( &self, num_photons: u32, c_res_deg: f32, g_res_deg: f32, source_flux: f32, cdf: &LvkCdf, primitives: &[GpuPrimitive], materials: &[GpuMaterial], ) -> GpuDetectorResult
Trace from an LDT source (FromLvk) with optional cover geometry.